# Inference

::: ode_filters.inference
    handler: python
    options:
        show_object_full_path: true
        show_source: false
        members_order: source
        show_signature_annotations: true
